#ifndef HTTVERSION_H
#define HTTVERSION_H

#define HTTQTVERSION  "1.4.4"
#define PROGRAM_DATE  "17 Jul 2014"

#define USE_QT_VERSION  4

#endif
